==> trade-center-api-2.4.32.1-20220707.043749-1-sources.jar: cn/com/duiba/order/center/api/dto/pipixia/PipiXiaAfterSalePushParam.java <==
package cn.com.duiba.order.center.api.dto.pipixia;

import java.util.List;

public class PipiXiaAfterSalePushParam {
    /**
     * 平台售后单号
     */
    private String afterSaleNo;

    /**
     * 关联平台订单号-兑吧订单号
     */
    private String orderId;

    /**
     * 售后单据类型
     * 2: 退货退款
     * 3: 仅退款
     */
    private Integer afterSaleType;

    /**
     * 售后单状态：
     * 待售后: wait
     * 售后取消:canceled
     * 售后拒绝:  reject
     *  同意售后: agree
     *  售后完成: success
     */
    private String afterSaleStatus;

    /**
     * yyyy-MM-dd HH:mm:ss
     */
    private String afterSaleApplyTime;

    /**
     * 售后原因
     */
    private String afterSaleReason;

    /**
     * 退货物流单号
     */
    private String returnTrackingNo;

    /**
     * 退货物流公司名称
     */
    private String returnLogisticsCompanyName;

    /**
     * 退货物流公司编码
     */
    private String returnLogisticsCompanyNo;

    /**
     * 退回收件人姓名
     */
    private String returnBackReceiverName;

    /**
     * 退回收件人电话
     */
    private String returnBackReceiverMobile;

    /**
     * 退回收件人地址
     */
    private String returnBackReceiverAddress;

    /**
     * 买家备注
     */
    private String buyerRemark;

    /**
     * 卖家备注
     */
    private String sellerRemark;


    /**
     * 售后单SKU详情
     * 类型为AfterSaleDetail
     */
    private List<AfterSaleDetail> afterSaleDetailList;


    class AfterSaleDetail{
        /**
         * 平台子订单号
         */
        private String subOrderId;

        /**
         * 平台sku编码
         */
        private String platformSkuNo;

        /**
         * 退货数量
         */
        private Integer quantity;

        /**
         * 申请退款⾦额
         * 单位（分）
         */
        private Long returnAmount;

        public String getSubOrderId() {
            return subOrderId;
        }

        public void setSubOrderId(String subOrderId) {
            this.subOrderId = subOrderId;
        }

        public String getPlatformSkuNo() {
            return platformSkuNo;
        }

        public void setPlatformSkuNo(String platformSkuNo) {
            this.platformSkuNo = platformSkuNo;
        }

        public Integer getQuantity() {
            return quantity;
        }

        public void setQuantity(Integer quantity) {
            this.quantity = quantity;
        }

        public Long getReturnAmount() {
            return returnAmount;
        }

        public void setReturnAmount(Long returnAmount) {
            this.returnAmount = returnAmount;
        }
    }


    public String getAfterSaleNo() {
        return afterSaleNo;
    }

    public void setAfterSaleNo(String afterSaleNo) {
        this.afterSaleNo = afterSaleNo;
    }

    public String getOrderId() {
        return orderId;
    }

    public void setOrderId(String orderId) {
        this.orderId = orderId;
    }

    public Integer getAfterSaleType() {
        return afterSaleType;
    }

    public void setAfterSaleType(Integer afterSaleType) {
        this.afterSaleType = afterSaleType;
    }

    public String getAfterSaleStatus() {
        return afterSaleStatus;
    }

    public void setAfterSaleStatus(String afterSaleStatus) {
        this.afterSaleStatus = afterSaleStatus;
    }

    public String getAfterSaleApplyTime() {
        return afterSaleApplyTime;
    }

    public void setAfterSaleApplyTime(String afterSaleApplyTime) {
        this.afterSaleApplyTime = afterSaleApplyTime;
    }

    public String getAfterSaleReason() {
        return afterSaleReason;
    }

    public void setAfterSaleReason(String afterSaleReason) {
        this.afterSaleReason = afterSaleReason;
    }

    public String getReturnTrackingNo() {
        return returnTrackingNo;
    }

    public void setReturnTrackingNo(String returnTrackingNo) {
        this.returnTrackingNo = returnTrackingNo;
    }

    public String getReturnLogisticsCompanyName() {
        return returnLogisticsCompanyName;
    }

    public void setReturnLogisticsCompanyName(String returnLogisticsCompanyName) {
        this.returnLogisticsCompanyName = returnLogisticsCompanyName;
    }

    public String getReturnLogisticsCompanyNo() {
        return returnLogisticsCompanyNo;
    }

    public void setReturnLogisticsCompanyNo(String returnLogisticsCompanyNo) {
        this.returnLogisticsCompanyNo = returnLogisticsCompanyNo;
    }

    public String getReturnBackReceiverName() {
        return returnBackReceiverName;
    }

    public void setReturnBackReceiverName(String returnBackReceiverName) {
        this.returnBackReceiverName = returnBackReceiverName;
    }

    public String getReturnBackReceiverMobile() {
        return returnBackReceiverMobile;
    }

    public void setReturnBackReceiverMobile(String returnBackReceiverMobile) {
        this.returnBackReceiverMobile = returnBackReceiverMobile;
    }

    public String getReturnBackReceiverAddress() {
        return returnBackReceiverAddress;
    }

    public void setReturnBackReceiverAddress(String returnBackReceiverAddress) {
        this.returnBackReceiverAddress = returnBackReceiverAddress;
    }

    public String getBuyerRemark() {
        return buyerRemark;
    }

    public void setBuyerRemark(String buyerRemark) {
        this.buyerRemark = buyerRemark;
    }

    public String getSellerRemark() {
        return sellerRemark;
    }

    public void setSellerRemark(String sellerRemark) {
        this.sellerRemark = sellerRemark;
    }

    public List<AfterSaleDetail> getAfterSaleDetailList() {
        return afterSaleDetailList;
    }

    public void setAfterSaleDetailList(List<AfterSaleDetail> afterSaleDetailList) {
        this.afterSaleDetailList = afterSaleDetailList;
    }
}

==> trade-center-api-3.0.14-sources.jar: cn/com/duiba/order/center/api/dto/pipixia/PipiXiaAfterSalePushParam.java <==
package cn.com.duiba.order.center.api.dto.pipixia;

import java.io.Serializable;

/**
 * @author fja
 */
public class PipiXiaAfterSalePushParam implements Serializable {
    /**
     * 平台售后单号
     */
    private String afterSaleNo;

    /**
     * 关联平台订单号-兑吧订单号
     */
    private String orderId;

    /**
     * 售后单据类型
     * 2: 退货退款
     * 3: 仅退款
     */
    private String afterSaleType;

    /**
     * 售后单状态：
     * 待售后: wait
     * 售后取消:canceled
     * 售后拒绝:  reject
     * 同意售后: agree
     * 售后完成: success
     */
    private String afterSaleStatus;

    /**
     * yyyy-MM-dd HH:mm:ss
     */
    private String afterSaleApplyTime;

    /**
     * 售后原因
     */
    private String afterSaleReason;

    /**
     * 退货物流单号
     */
    private String returnTrackingNo;

    /**
     * 退货物流公司名称
     */
    private String returnLogisticsCompanyName;

    /**
     * 退货物流公司编码
     */
    private String returnLogisticsCompanyNo;

    /**
     * 退回收件人姓名
     */
    private String returnBackReceiverName;

    /**
     * 退回收件人电话
     */
    private String returnBackReceiverMobile;

    /**
     * 退回收件人地址
     */
    private String returnBackReceiverAddress;

    /**
     * 买家备注
     */
    private String buyerRemark;

    /**
     * 卖家备注
     */
    private String sellerRemark;


    /**
     * 售后单SKU详情
     * 类型为AfterSaleDetail json数组字符串
     */
    private String afterSaleDetailList;


    public static class AfterSaleDetail implements Serializable {
        /**
         * 平台子订单号
         */
        private String subOrderId;

        /**
         * 平台sku编码
         */
        private String platformSkuNo;

        /**
         * 退货数量
         */
        private Integer quantity;

        /**
         * 申请退款⾦额
         * 单位（分）
         */
        private Long returnAmount;

        public String getSubOrderId() {
            return subOrderId;
        }

        public void setSubOrderId(String subOrderId) {
            this.subOrderId = subOrderId;
        }

        public String getPlatformSkuNo() {
            return platformSkuNo;
        }

        public void setPlatformSkuNo(String platformSkuNo) {
            this.platformSkuNo = platformSkuNo;
        }

        public Integer getQuantity() {
            return quantity;
        }

        public void setQuantity(Integer quantity) {
            this.quantity = quantity;
        }

        public Long getReturnAmount() {
            return returnAmount;
        }

        public void setReturnAmount(Long returnAmount) {
            this.returnAmount = returnAmount;
        }
    }


    public String getAfterSaleNo() {
        return afterSaleNo;
    }

    public void setAfterSaleNo(String afterSaleNo) {
        this.afterSaleNo = afterSaleNo;
    }

    public String getOrderId() {
        return orderId;
    }

    public void setOrderId(String orderId) {
        this.orderId = orderId;
    }

    public String getAfterSaleType() {
        return afterSaleType;
    }

    public void setAfterSaleType(String afterSaleType) {
        this.afterSaleType = afterSaleType;
    }

    public String getAfterSaleStatus() {
        return afterSaleStatus;
    }

    public void setAfterSaleStatus(String afterSaleStatus) {
        this.afterSaleStatus = afterSaleStatus;
    }

    public String getAfterSaleApplyTime() {
        return afterSaleApplyTime;
    }

    public void setAfterSaleApplyTime(String afterSaleApplyTime) {
        this.afterSaleApplyTime = afterSaleApplyTime;
    }

    public String getAfterSaleReason() {
        return afterSaleReason;
    }

    public void setAfterSaleReason(String afterSaleReason) {
        this.afterSaleReason = afterSaleReason;
    }

    public String getReturnTrackingNo() {
        return returnTrackingNo;
    }

    public void setReturnTrackingNo(String returnTrackingNo) {
        this.returnTrackingNo = returnTrackingNo;
    }

    public String getReturnLogisticsCompanyName() {
        return returnLogisticsCompanyName;
    }

    public void setReturnLogisticsCompanyName(String returnLogisticsCompanyName) {
        this.returnLogisticsCompanyName = returnLogisticsCompanyName;
    }

    public String getReturnLogisticsCompanyNo() {
        return returnLogisticsCompanyNo;
    }

    public void setReturnLogisticsCompanyNo(String returnLogisticsCompanyNo) {
        this.returnLogisticsCompanyNo = returnLogisticsCompanyNo;
    }

    public String getReturnBackReceiverName() {
        return returnBackReceiverName;
    }

    public void setReturnBackReceiverName(String returnBackReceiverName) {
        this.returnBackReceiverName = returnBackReceiverName;
    }

    public String getReturnBackReceiverMobile() {
        return returnBackReceiverMobile;
    }

    public void setReturnBackReceiverMobile(String returnBackReceiverMobile) {
        this.returnBackReceiverMobile = returnBackReceiverMobile;
    }

    public String getReturnBackReceiverAddress() {
        return returnBackReceiverAddress;
    }

    public void setReturnBackReceiverAddress(String returnBackReceiverAddress) {
        this.returnBackReceiverAddress = returnBackReceiverAddress;
    }

    public String getBuyerRemark() {
        return buyerRemark;
    }

    public void setBuyerRemark(String buyerRemark) {
        this.buyerRemark = buyerRemark;
    }

    public String getSellerRemark() {
        return sellerRemark;
    }

    public void setSellerRemark(String sellerRemark) {
        this.sellerRemark = sellerRemark;
    }

    public String getAfterSaleDetailList() {
        return afterSaleDetailList;
    }

    public void setAfterSaleDetailList(String afterSaleDetailList) {
        this.afterSaleDetailList = afterSaleDetailList;
    }
}
